This project is written and maintained by Fang Li and
various contributors:


Django Saml2 Auth
-----------------

- Fang Li



Pysaml2
-------

- Roland Hedberg and it's contributors



Contributors
------------

- `Gene Wood <http://github.com/gene1wood/>`_
- `Terry <https://github.com/tpeng>`_